==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Forzar al centro
Arremolinar los mapas de bits seleccionados alrededor de un punto central.
Arremolinar los mapas de bits seleccionados alrededor de un punto central</translatorcomment>
        <translation>Punto central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Punto de referencia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_es.ts--
Especifique punto de destino
Punto objetivo</translatorcomment>
        <translation>Punto objetivo</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotar</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Opciones de rotación</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Número de copias</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Eliminar original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Conservar original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copias &amp;múltiples</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>Á&amp;ngulo (a):</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_es.ts--
Usar capa y los &amp;atributos actual</translatorcomment>
        <translation>Usar capa y los &amp;atributos actual</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Rotate/ts/Rotate_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Rotate</name>
    <message>
        <location filename="../Rotate.js" line="+70"/>
        <source>Center point</source>
        <translatorcomment>--google--
Forzar al centro
Arremolinar los mapas de bits seleccionados alrededor de un punto central.
Arremolinar los mapas de bits seleccionados alrededor de un punto central</translatorcomment>
        <translation>Punto central</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Reference point</source>
        <translation>Punto de referencia</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Target point</source>
        <translatorcomment>--exact match--
--file: IsoProject_es.ts--
Especifique punto de destino
Punto objetivo</translatorcomment>
        <translation>Punto objetivo</translation>
    </message>
    <message>
        <location filename="../RotateInit.js" line="+2"/>
        <source>&amp;Rotate</source>
        <translation>&amp;Rotar</translation>
    </message>
</context>
<context>
    <name>RotateOptions</name>
    <message>
        <location filename="../RotateDialog.ui" line="+14"/>
        <source>Rotate Options</source>
        <translation>Opciones de rotación</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translation>Número de copias</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translation>&amp;Eliminar original</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translation>&amp;Conservar original</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translation>Copias &amp;múltiples</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translation>Á&amp;ngulo (a):</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Define angle using mouse cursor</source>
        <translation>Definir ángulo con el cursor del ratón</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--exact match--
--file: Mirror_es.ts--
Usar capa y los &amp;atributos actual</translatorcomment>
        <translation>Usar capa y los &amp;atributos actual</translation>
    </message>
</context>
</TS>
